@@ -59,7 +59,7 @@ class TrelloCard(IssuePlugin):
     def can_enable_for_projects(self):
         return True
 
-    def is_configured(self, project):
+    def is_configured(self, request, project):
         return (
             all((self.get_option(key, project)
                 for key in ('key', 'token', 'board_list'))
